/**
 * LoginController.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('controllers/login/logincontroller',
		['app',
		 'shared/keys',
		 'shared/urlcatalog',
		 'utils/validationutils',
		 'nls/i18nhelper',
		 'ember',
		 'cordova'],
		 function(Filmeet, Keys, UrlCatalog, ValidationUtils, I18nHelper){
	console.log('Defining LoginController');
	Filmeet.LoginController = Ember.ObjectController.extend({
		// Properties
		/** Username written in first text input. */
		username: null,
		/** User password written in password text input. */
		password: null,
		// Functions
		/**
		 * Transitions to Register screen
		 */
		goToRegister: function(){
			this.transitionToRoute('register');
		},
		/**
		 * Logs the user into the app.
		 */
		checkLogin: function(){
			var self = this;
			var username = self.get('username');
	        var password = self.get('password');
	        
	        var emptyUsername = ValidationUtils.isEmptyOrNullString(username);
	        var emptyPassword = ValidationUtils.isEmptyOrNullString(password);
	        if(!emptyUsername && !emptyPassword){
	        	console.log('Logging in user with username: '+username);
				
				$.ajax({
					type: 'POST',
					url: UrlCatalog.get('checkLogin'),
					cache: false,
					data: {'username': username, 'password': password},
					success: function(data){
						if(data && data != null){
							console.log('Login succeded :-)');
							localStorage.setItem(Keys.username, username);
							localStorage.setItem(Keys.authorizationHash, data);
							self.transitionToRoute('app.home');
						} else {
							var errorMsg = I18nHelper.getValueFromKey('errorLogin');
							navigator.notification.alert(errorMsg, function(){}, I18nHelper.getValueFromKey('errors'));
							localStorage.removeItem(Keys.username);
							localStorage.removeItem(Keys.authorizationHash);
						}
					},
					error: function(jqXHR, textStatus, errorThrown){
						console.log('Login failed :-(');
						console.log('Error');
						console.log(JSON.stringify(jqXHR));
						console.log(textStatus);
						console.log(errorThrown);
						localStorage.removeItem(Keys.username);
						localStorage.removeItem(Keys.authorizationHash);
					}
				});
	        } else {
	        	var errors = "";
	        	if(emptyUsername){
	        		errors = I18nHelper.getValueFromKey('errorEmptyUsername');
	        		if(emptyPassword){
	        			errors = errors + "\n";
	        		}
	        	}
	        	if(emptyPassword){
	        		errors = errors + I18nHelper.getValueFromKey('errorEmptyPassword');
	        	}
	        	navigator.notification.alert(errors, function(){}, I18nHelper.getValueFromKey('errors'));
	        }
		}
	});
});