/**
 * MeetingsNewStepTwoController.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('controllers/meetings/newsteptwo/meetingsnewsteptwocontroller',
		['app',
		 'utils/validationutils',
		 'nls/i18nhelper',
		 'shared/urlcatalog',
		 'shared/keys',
		 'ember',
		 'models/meeting/meeting',
		 'models/member/member',
		 'cordova'],
		 function(Filmeet, ValidationUtils, I18nHelper, UrlCatalog, Keys){
	console.log('Defining MeetingsNewStepTwoController');
	Filmeet.MeetingsNewStepTwoController = Ember.Controller.extend({
		newMeeting: null,
		invitedFriends: [],
		friends: [],
		searchText: null,
		creatorGotIt: false,
		goToVote: function(){
			var self = this;
			var meetingMembers = self.get('invitedFriends');
			var meetingMembersSize = meetingMembers.length;
			if(meetingMembers.length > 0){
				
				var createdMeeting = self.get('newMeeting');
				
				var membersUserSidArray = [];
				var membersGotItArray = [];
				var someoneGotIt = false;
				for(var index = 0; index < meetingMembersSize; index++){
					membersUserSidArray[index] = meetingMembers[index].get('userSid');
					membersGotItArray[index] = meetingMembers[index].get('gotIt');
					if(meetingMembers[index].get('gotIt')){
						someoneGotIt = true;
					}
				}
				
				// Adding creator as a member of his meeting
				membersUserSidArray.push(localStorage.getItem(Keys.username));
				membersGotItArray.push(this.get('creatorGotIt'));
				someoneGotIt = someoneGotIt || this.get('creatorGotIt');
				
				if(createdMeeting.get('inCinema') || someoneGotIt){
					$.ajax({
						type: 'POST',
						cache: false,
						url: UrlCatalog.get('saveNewMeeting'),
						data: {'name': createdMeeting.get('name'),
							'numberCandidates':  createdMeeting.get('numberCandidates'),
							'inCinema':  createdMeeting.get('inCinema'),
							'notSeen':  createdMeeting.get('notSeen'),
							'memberUserSidList': membersUserSidArray,
							'memberGotItList': membersGotItArray,
							'date': createdMeeting.get('date').getTime(),
							'hash': localStorage.getItem(Keys.authorizationHash)},
						dataType:'json',
						success: function(data){
							createdMeeting.set('sid', data);
							self.transitionToRoute('oneMeeting.details', createdMeeting.get('sid'));
						},
						error: function(jqXHR, textStatus, errorThrown){
							navigator.notification.alert(I18nHelper.getValueFromKey('errorNoGotItFriend'), function(){}, I18nHelper.getValueFromKey('errors'));
						}
					});
				} else {
					navigator.notification.alert(I18nHelper.getValueFromKey('errorNoGotItFriend'), function(){}, I18nHelper.getValueFromKey('errors'));
				}				
			} else {
				navigator.notification.alert(I18nHelper.getValueFromKey('errorNoInvitedFriends'), function(){}, I18nHelper.getValueFromKey('errors'));
			}
		},
		searchFriends: function(){
			var searchedText = this.get('searchText');
			var invitedFriends = this.get('invitedFriends');
			
			var usernameInvitedFriends = [];
			var invitedLength = invitedFriends.length;
			if(invitedLength > 0){
				for(var i = 0; i < invitedLength; i++){
					var username = invitedFriends[i].get('userSid');
					usernameInvitedFriends.addObject(username);
				}
			}
			if (usernameInvitedFriends.length == 0){
				usernameInvitedFriends = [''];
			}
			
			var results = [];
			$.ajax({
				type: 'GET',
				cache: false,
				url: UrlCatalog.get('searchFriendsForMeeting'),
				data: {'words': searchedText, 'users': usernameInvitedFriends, 'hash': localStorage.getItem(Keys.authorizationHash)},
				dataType:'json',
				success: function(data){
					data.forEach(function(friendAndBlocked){
						results.addObject(Filmeet.Member.create({
							userSid: friendAndBlocked.username
						}));
					});
				}
			});
			
			this.set('friends', results);
			
		}.observes('searchText'),
		addToInvitationList: function(friend){
			if(!this.get('invitedFriends').contains(friend)){
				this.get('invitedFriends').addObject(friend);
				this.get('friends').removeObject(friend);
			}
		},
		deleteFromInvitationList: function(friend){
			this.get('invitedFriends').removeObject(friend);
			this.searchFriends();
		},
		markAsgotIt: function(friend){
			if(!friend.get('gotIt')){
				friend.set('gotIt', true);
			} else {
				friend.set('gotIt', false);
			}
		},
		markCreatorgotIt: function(){
			if(!this.get('creatorGotIt')){
				this.set('creatorGotIt', true);
			} else {
				this.set('creatorGotIt', false);
			}
		}
	});
});