/**
 * RegisterController. This class handles the Register screen's events.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('controllers/register/registercontroller',
		['app',
		 'shared/keys',
		 'shared/urlcatalog',
		 'utils/validationutils',
		 'nls/i18nhelper',
		 'cordova',
		 'ember'],
		 function(Filmeet, Keys, UrlCatalog, ValidationUtils, I18nHelper){
	console.log('Defining RegisterController');
	Filmeet.RegisterController = Ember.ObjectController.extend({
		// Properties
		/** User email written in the second input. */
		userEmail: null,
		/** User name written in the first input. */
		username: null,
		/** User password written in the third input. */
		password: null,
		// Functions
		/**
		 * Transitions to Login screen.
		 */
		goToLogin: function(){
			this.transitionToRoute('login');
		},
		/**
		 * Registers a new user and logs it into the app when it's done.
		 */
		registerUser: function(){
			var self = this;
			var email = this.get('userEmail');
			var username = this.get('username');
			var password = this.get('password');
			
			var validEmail = ValidationUtils.isValidEmail(email);
			var emptyUsername = ValidationUtils.isEmptyOrNullString(username);
			var emptyPassword = ValidationUtils.isEmptyOrNullString(password);
			
			if(validEmail
					&& !emptyUsername
					&& !emptyPassword){
				$.ajax({
					type: 'POST',
					url: UrlCatalog.get('registerUser'),
					cache: false,
					data: {'username': username, 'email': email, 'password': password},
					dataType: 'json',
					success: function(data){
						if(data && data.a){
							console.log('Register succeded :-)');
							localStorage.setItem(Keys.username, username);
							localStorage.setItem(Keys.authorizationHash, data.b);
							self.transitionToRoute('app.home');
						} else {
							var errorMsg = I18nHelper.getValueFromKey('errorExistingUser');
							navigator.notification.alert(errorMsg, function(){}, I18nHelper.getValueFromKey('errors'));
						}
					},
					error: function(jqXHR, textStatus, errorThrown){
						console.log('registerUser error');
						console.log(JSON.stringify(jqXHR));
						console.log(textStatus);
						console.log(errorThrown);
					}
				});
			} else {
				var errors = "";
				if(emptyUsername){
	        		errors = I18nHelper.getValueFromKey('errorEmptyUsername');
	        		if(!validEmail || emptyPassword){
	        			errors = errors + "\n";
	        		}
	        	}
				if(!validEmail){
					errors = errors + I18nHelper.getValueFromKey('errorEmail');
					if(emptyPassword){
	        			errors = errors + "\n";
	        		}
				}
	        	if(emptyPassword){
	        		errors = errors + I18nHelper.getValueFromKey('errorEmptyPassword');
	        	}
	        	navigator.notification.alert(errors, function(){}, I18nHelper.getValueFromKey('errors'));
			}
		}
	});
});