/**
 * UrlCatalog. This class contains all the urls which are calling the
 * WebServices we have.
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 */
define('shared/urlcatalog', function(){
	var localHostUrl = 'http://localhost:8080/';
	var productionUrl = 'http://192.168.0.10:8080/';
	var isProduction = true;
	
	var url;
	if (isProduction){
		url = productionUrl;
	}
	else{
		url = localHostUrl;
	}
	
	var urls = {
		/*
		 * LoginController
		 */
		checkLogin: url+'Filmeet/rest/login/check',
		checkLoginLocalStorage: url+'Filmeet/rest/login/checkLocalStorage',
		/*
		 * RegisterController
		 */
		registerUser: url+'Filmeet/rest/register/new',
		/*
		 * User model
		 */
		getLoggedUser: url+'Filmeet/rest/login/show',
		getAllFriends: url+'Filmeet/rest/friends/me',
		searchNotFriends: url+'Filmeet/rest/friends/searchnotfriends',
		addFriend: url+'Filmeet/rest/friends/create',
		/*
		 * Film model
		 */
		getFilmFromSid: url+'Filmeet/rest/film/',
		getMyFilmsWithFilters: url+'Filmeet/rest/profile/films/filters',
		getMyFilms: url+'Filmeet/rest/profile/films',
		saveNewFilm: url+'Filmeet/rest/film/create',
		search: url+'Filmeet/rest/film/search',
		lastSevenFilms: url+'Filmeet/rest/home/last7films',
		getCandidates: url+'Filmeet/rest/meetings/candidates',
		/*
		 * FriendsController
		 */
		blockFriend: url+'Filmeet/rest/friends/block',
		/*
		 * FilmLibrary model
		 */
		getFilmLibrary: url+'Filmeet/rest/filmlibrary/get',
		updateFilmStatus: url+'Filmeet/rest/filmlibrary/update',
		addToFilmLibrary: url+'Filmeet/rest/filmlibrary/add',
		/*
		 * ConfigurationController
		 */
		editUser: url+'Filmeet/rest/configuration/edit',
		getUser: url+'Filmeet/rest/configuration/get',
		/*
		 * MeetingsNewStepTwoController
		 */
		searchFriendsForMeeting: url+'Filmeet/rest/createmeeting/search',
		saveNewMeeting: url+'Filmeet/rest/createmeeting/create',
		/*
		 * Meeting model
		 */
		getMeeting: url+'Filmeet/rest/meetings/get',
		getAllMyMeetings: url+'Filmeet/rest/meetings/me',
		getAllMyNextMeetings: url+'Filmeet/rest/home/nextmeetings',
		/*
		 * OneMeetingVoteController
		 */
		vote: url+'Filmeet/rest/vote/accept',
		/*
		 * Notification model
		 */
		getNotifications: url+'Filmeet/rest/notifications/get',
		checkNewNotifications: url+'Filmeet/rest/notifications/news',
		markAsSeen: url+'Filmeet/rest/notifications/seen',
		/*
		 * Member model
		 */
		getAllFromMeeting: url+'Filmeet/rest/meetings/allmember',
		/*
		 * Candidate model
		 */
		getRankingFilms: url+'Filmeet/rest/meetings/rankingfilms'
	}
	
	return {
		get: function(key){
			try{
				if(urls[key]){
					return urls[key];
				} else {
					throw "The key '"+key+"' doesn't exist in the url catalog";
				}
			} catch (e) {
				console.error(e);
			}
		}
	}
});