/**
 * Time utilities.
 * @author Alejandro Arnáiz González, deathnew[at]gmail.com
 * @author Diego Crenes Carrera, dcrenes[at]gmail.com
 */
define('utils/timeutils',
		['nls/i18nhelper',
		 'ember'],
		function(I18nHelper){
	// Day array
	var daysArray = [];
	for(var i=0; i<=30; i++){
		daysArray[i] = i+1;
	}
	// Month array
	var monthsArray = [
	   Ember.Object.create({monthNumber: 1, monthName: I18nHelper.getValueFromKey('january')}),
	   Ember.Object.create({monthNumber: 2, monthName: I18nHelper.getValueFromKey('february')}),
	   Ember.Object.create({monthNumber: 3, monthName: I18nHelper.getValueFromKey('march')}),
	   Ember.Object.create({monthNumber: 4, monthName: I18nHelper.getValueFromKey('april')}),
	   Ember.Object.create({monthNumber: 5, monthName: I18nHelper.getValueFromKey('may')}),
	   Ember.Object.create({monthNumber: 6, monthName: I18nHelper.getValueFromKey('june')}),
	   Ember.Object.create({monthNumber: 7, monthName: I18nHelper.getValueFromKey('july')}),
	   Ember.Object.create({monthNumber: 8, monthName: I18nHelper.getValueFromKey('august')}),
	   Ember.Object.create({monthNumber: 9, monthName: I18nHelper.getValueFromKey('september')}),
	   Ember.Object.create({monthNumber: 10, monthName: I18nHelper.getValueFromKey('october')}),
	   Ember.Object.create({monthNumber: 11, monthName: I18nHelper.getValueFromKey('november')}),
	   Ember.Object.create({monthNumber: 12, monthName: I18nHelper.getValueFromKey('december')}),
	];
	// Year array
	var yearsArray = [];
	for(var i=0; i<5; i++){
		yearsArray[i] = 2013 + i;
	}
	// Hour array
	var hoursArray = [];
	for(var i = 0; i<=23; i++){
		var hourString = ""+i;
		if(i < 10){
			hourString = "0"+hourString;
		}
		hoursArray[i] = hourString;
	}
	// Minutes array
	var minutesArray = [];
	for(var i = 0; i<=59; i++){
		var minutesString = ""+i;
		if(i < 10){
			minutesString = "0"+minutesString;
		}
		minutesArray[i] = minutesString;
	}
	
	return{
		/**
		 * Returns an array of days.
		 */
		getDays: function(){
			return daysArray;
		},
		/**
		 * Returns an array of months.
		 */
		getMonths: function(){
			return monthsArray;
		},
		/**
		 * Returns an array of years.
		 */
		getYears: function(){
			return yearsArray;
		},
		/**
		 * Returns an array of hours.
		 */
		getHours: function(){
			return hoursArray;
		},
		/**
		 * Returns an array of minutes.
		 */
		getMinutes: function(){
			return minutesArray;
		},
		/**
		 * Returns now's day.
		 */
		getNowDay: function(){
			var d = new Date();
			return daysArray[d.getDate()-1];
		},
		/**
		 * Returns now's month.
		 */
		getNowMonth: function(){
			var d = new Date();
			return monthsArray[d.getMonth()];
		},
		/**
		 * Returns now's year.
		 */
		getNowYear: function(){
			var d = new Date();
			var offset = 2013 - d.getFullYear();
			return yearsArray[offset]; 
		},
		/**
		 * Returns now's hour.
		 */
		getNowHour: function(){
			var d = new Date();
			return hoursArray[d.getHours()]; 
		},
		/**
		 * Returns now's minutes.
		 */
		getNowMinute: function(){
			var d = new Date();
			return minutesArray[d.getMinutes()]; 
		}
	}
});